import _extends from "@babel/runtime/helpers/extends";
import React, { memo } from 'react';
import { Theme } from '../theme';
import Container from './container';
import Content from './content';

/**
 * __Lozenge__
 *
 * A lozenge is a visual indicator used to highlight an item's status for quick recognition.
 *
 * - [Examples](https://atlassian.design/components/lozenge/examples)
 * - [Code](https://atlassian.design/components/lozenge/code)
 * - [Usage](https://atlassian.design/components/lozenge/usage)
 */
const Lozenge = /*#__PURE__*/memo(({
  theme,
  children,
  testId,
  isBold = false,
  appearance = 'default',
  maxWidth = 200
}) => {
  const props = {
    theme,
    children,
    testId,
    isBold,
    appearance,
    maxWidth
  };
  return /*#__PURE__*/React.createElement(Theme.Provider, {
    value: theme
  }, /*#__PURE__*/React.createElement(Theme.Consumer, props, themeTokens => /*#__PURE__*/React.createElement(Container, _extends({
    testId: testId
  }, themeTokens), /*#__PURE__*/React.createElement(Content, themeTokens, children))));
});
Lozenge.displayName = 'Lozenge';
export default Lozenge;